<?php

namespace Drupal\currency_pbank;

/**
 * Privatbank.ua API Interface.
 */
interface PrivatBankRateApiInterface {

  /**
   * Privatbank API Public endpoint.
   */
  const P24_API_PUBINFO_URL = 'https://api.privatbank.ua/p24api/pubinfo';

  /**
   * Cash rate type in Privatbank branches.
   */
  const P24_API_RATE_TYPE_CASH = 5;

  /**
   * Cashless rate type (conversion by cards, Privat24, deposit replenishment).
   */
  const P24_API_RATE_TYPE_CASHLESS = 11;

  /**
   * Gets currency codes privatbank provides rating for.
   *
   * @return string
   */
  public function getAvailableCurrencies();

  /**
   * Gets Privatbank currency exchange rate.
   *
   * @param string $currency_code
   *   Currency code.
   * @param string $type
   *   Rate type: buy or sale (buy by default).
   * @param bool $cashless
   *   True to get cashless exchange rate, false to get cash rate.
   *
   * @return float|null
   *   Exchange rate if found or NULL.
   *
   * @throws \InvalidArgumentException
   */
  public function getRate($currency_code, $type = 'buy', bool $cashless = TRUE);

}
